@@ -30,7 +30,7 @@ void EnvironmentSettingsRulesPage::setRules(const QString &rules)
     const QString information =
         "<qt><b>"_L1 + i18n("These rules cannot be edited with this application. You need to set them in QT_LOGGING_RULES variable directly.") + "</b><qt>"_L1;
     QString newRules = rules;
-    mRichTextEdit->setHtml(information + i18n("Current rules:") + QStringLiteral("<br>") + newRules.replace(QLatin1Char('\n'), "<br>"_L1));
+    mRichTextEdit->setHtml(information + i18n("Current rules:") + u"<br>"_s + newRules.replace(u'\n', "<br>"_L1));
 }
 
 #include "moc_environmentsettingsrulespage.cpp"
